@@ -1,7 +1,7 @@
 package Math::ScientificNotation::Util;
 
 our $DATE = '2016-06-17'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use Exporter qw(import);
 our @EXPORT_OK = qw(sci2dec);
@@ -10,7 +10,7 @@ sub sci2dec {
     my $num = shift;
     die "Please specify a number" unless defined $num;
 
-    if ($num =~ /\A(?:[+-]?)(?:\d+\.|\d*\.(\d+))[eE]([+-]?\d+)\z/) {
+    if ($num =~ /\A(?:[+-]?)(?:\d+\.?|\d*\.(\d+))[eE]([+-]?\d+)\z/) {
         my $num_digs_after_dec = length($1 || "") - $2;
         $num_digs_after_dec = 0 if $num_digs_after_dec < 0;
         return sprintf("%.${num_digs_after_dec}f", $num);
@@ -37,7 +37,7 @@ Math::ScientificNotation::Util - Utilities related to scientific notation
 
 =head1 VERSION
 
-This document describes version 0.002 of Math::ScientificNotation::Util (from Perl distribution Math-ScientificNotation-Util), released on 2016-06-17.
+This document describes version 0.003 of Math::ScientificNotation::Util (from Perl distribution Math-ScientificNotation-Util), released on 2016-06-17.
 
 =head1 SYNOPSIS
 
